# timetappy

## What is this repository for?

Unoffical [TimeTap API](https://www.timetap.com/online-scheduling-api.html) client for Python.

API docs available here: https://timetap.atlassian.net/wiki/spaces/TTAPI/overview

This library is far from finished.

## Requirements

* Python 3
* [Requests](https://pypi.org/project/requests/)
